#include "stdint.h"
#include <libusb-1.0/libusb.h>
#include "libusb.h"

DeviceID ID_ICHUT[] = {{0x4242, 0x0001, 1},
                       {-1,     -1}};

/**
 * Sends data to the device
 * @param noise_stage_1 Noise level for stage 1
 * @param noise_stage_2 Noise level for stage 2
 * @param noise_stage_3 Noise level for stage 3
 */
void send_data(uint16_t noise_stage_1, uint16_t noise_stage_2, uint16_t noise_stage_3) {
    if (nb_devices == 0) {
        printf("No device found\n");
        return;
    }
    int out = devices[0].out[0].address;
    int size;

    uint16_t table[] = {noise_stage_1, noise_stage_2, noise_stage_3};

    int status = libusb_interrupt_transfer(devices[0].handle, out, (char *) &table, sizeof(uint16_t) * 3, &size, 1000);
    if (status < 0) {
        perror("sendData.libusb_interrupt_transfer");
        exit(-1);
    }
}

/**
 * Main
 * @return
 */
int main(argc, argv) {
    // Stage 1
    uint16_t noise_stage_1 = 0;
    do {
        printf("Enter a number for noise stage 1:\n");
        scanf("%hd", &noise_stage_1);
    } while (noise_stage_1 < 0 || noise_stage_1 > 255);

    // Stage 2
    uint16_t noise_stage_2 = 0;
    do {
        printf("Enter a number for noise stage 2:\n");
        scanf("%hd", &noise_stage_2);
    } while (noise_stage_2 < 0 || noise_stage_2 > 255);

    // Stage 3
    uint16_t noise_stage_3 = 0;
    do {
        printf("Enter a number for noise stage 3:\n");
        scanf("%hd", &noise_stage_3);
    } while (noise_stage_3 < 0 || noise_stage_3 > 255);

    // Send data
    scan_for_devices(ID_ICHUT);
    configure_devices();
    send_data(noise_stage_1, noise_stage_2, noise_stage_3);
    close_devices();

    printf("Data sent\nPlease restart the device\n");
    return 1;
}

